@@ -761,8 +761,8 @@ def Reports(df_list,list_name,bodypart,fields=None,filter=0.3,fps=30):
   
     if type(fields) != type(None):  
         for i in range(len(fields)):
-            relatorio["field{0}".format(i+1)] = []
-            relatorio["time_field{0}".format(i+1)] = []
+            relatorio["field_{0}".format(i+1)] = []
+            relatorio["time_field_{0}".format(i+1)] = []
 
     for i,v in enumerate(df_list):
         lista = [list_name[i]]
@@ -843,9 +843,10 @@ def DrawLine(x, y, angle, **kwargs):
     else:
         return ax.arrow(x, y, arrow_size*np.cos(angle), arrow_size*np.sin(angle),width = arrow_width,head_width=head_width,fc = arrow_color)
 
-def HeadOrientation(data, step, head = "", tail = "", **kwargs):
+def HeadOrientation(data, step, head = None, tail = None, **kwargs):
     """
     Plots the trajectory of the determined body part.
+
     Parameters
     ----------
     data : pandas DataFrame
@@ -910,14 +911,17 @@ def HeadOrientation(data, step, head = "", tail = "", **kwargs):
         Determines the arrow color.
     arrow_size : int, optional
         Determines the arrow size.
+
     Returns
     -------
     out : plot
         The output of the function is the figure with the tracking plot of the 
         selected body part.
+
     See Also
     --------
     For more information and usage examples: https://github.com/pyratlib/pyrat
+
     Notes
     -----
     This function was developed based on DLC outputs and is able to support 
@@ -1236,6 +1240,7 @@ def LFP(data):
 def PlotInteraction(interactions, **kwargs):
   """
   Plots a bar with interactions times of the determined body with the fields.
+
   Parameters
   ----------
   interactions : pandas DataFrame
@@ -1403,4 +1408,107 @@ def Blackrock(data_path, freq):
     df = pd.DataFrame(values,columns=channels,index= None) 
     df.insert(0, "Time", time, True)
 
-    return df
\ No newline at end of file
+    return df
+
+def ClassifyBehavior(data, bp_1="snout",bp_2="ear_L", bp_3="ear_R", bp_4="tail", dimensions = 2,distance=28,**kwargs):
+    """
+    Returns an array with the cluster by frame, an array with the embedding data in low-dimensional space and the clusterization model.
+    
+    Parameters
+    ----------
+    data : pandas DataFrame
+        The input tracking data.
+    bp_1 : str
+        Body part representing snout.
+    bp_2 : str
+        Body part representing left ear.
+    bp_3 : str
+        Body part representing right ear.
+    bp_4 : str
+        Body part representing tail.
+    dimensions : int
+        Dimension of the embedded space.
+    distance : int
+        The linkage distance threshold above which, clusters will not be merged.
+    startIndex : int, optional
+        Initial index.
+    n_jobs : int, optional
+        The number of parallel jobs to run for neighbors search.
+    verbose : int, optional
+        Verbosity level.
+    perplexity : float, optional
+        The perplexity is related to the number of nearest neighbors that is used in other manifold learning algorithms. Larger datasets usually require a larger perplexity.
+    
+    Returns
+    -------
+    cluster_labels : array
+        Array with the cluster by frame.
+    X_transformed : array
+        Embedding of the training data in low-dimensional space.
+    model : Obj
+        AgglomerativeClustering model.
+    
+    See Also
+    --------
+    For more information and usage examples: https://github.com/pyratlib/pyrat
+    
+    Notes
+    -----
+    This function was developed based on DLC outputs and is able to support 
+    matplotlib configurations."""
+    from sklearn.manifold import TSNE
+    from sklearn.cluster import AgglomerativeClustering
+    from sklearn.preprocessing import StandardScaler
+
+    startIndex = kwargs.get('startIndex')
+    n_jobs = kwargs.get('n_jobs')
+    verbose = kwargs.get('verbose')
+    perplexity = kwargs.get("perplexity")
+    if type(startIndex) == type(None):
+      startIndex = 0
+    if type(n_jobs) == type(None):
+      n_jobs=-1
+    if type(verbose) == type(None):
+      verbose=0
+    if type(perplexity) == type(None):
+      perplexity=500
+    
+    values = (data.iloc[2:,1:].values).astype(np.float)
+    lista1 = (data.iloc[0][1:].values +" - " + data.iloc[1][1:].values).tolist()
+
+    nose = np.concatenate(((values[:,lista1.index(bp_1+" - x")]).reshape(1,-1).T,(values[:,lista1.index(bp_1+" - y")]).reshape(1,-1).T), axis=1)
+    earr = np.concatenate(((values[:,lista1.index(bp_2+" - x")]).reshape(1,-1).T,(values[:,lista1.index(bp_2+" - y")]).reshape(1,-1).T), axis=1)
+    earl = np.concatenate(((values[:,lista1.index(bp_3+" - x")]).reshape(1,-1).T,(values[:,lista1.index(bp_3+" - y")]).reshape(1,-1).T), axis=1)
+    tail = np.concatenate(((values[:,lista1.index(bp_4+" - x")]).reshape(1,-1).T,(values[:,lista1.index(bp_4+" - y")]).reshape(1,-1).T), axis=1)
+
+    bodyparts = [nose, earr, earl, tail]
+    distances = []
+
+    for k in range(len(bodyparts[0])):
+        frame_distances = []
+        for i in range(len(bodyparts)):
+            distance_row = []
+            for j in range( len(bodyparts) ):
+                distance_row.append(np.linalg.norm(bodyparts[i][k] - bodyparts[j][k]))
+            frame_distances.append(distance_row)
+        distances.append(frame_distances)
+
+    distances2 = np.asarray(distances)
+
+    for i in range(4):
+      for k in range(4):
+          distances2[:, i, j] = distances2[:, i, j]/np.max(distances2[:, i, j])
+
+    d = []
+    for i in range(distances2.shape[0]):
+        d.append(distances2[i, np.triu_indices(4, k = 1)[0], np.triu_indices(4, k = 1)[1]])
+    
+    d = StandardScaler().fit_transform(d)
+
+    embedding = TSNE(n_components=dimensions, n_jobs=n_jobs, verbose=verbose, perplexity=perplexity)
+    X_transformed = embedding.fit_transform(d[startIndex:])
+    model = AgglomerativeClustering(n_clusters=None,distance_threshold=distance)
+    model = model.fit(d[startIndex:])
+    cluster_labels = model.labels_    
+
+    return cluster_labels, X_transformed, model
\ No newline at end of file
